==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/expression/impl/ArrayElementReferenceSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ArrayElementReference;
import io.ciera.tool.sql.architecture.expression.ArrayElementReferenceSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.List;


public class ArrayElementReferenceSetImpl extends InstanceSet<ArrayElementReferenceSet,ArrayElementReference> implements ArrayElementReferenceSet {

    // attributes
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setParent_name( ref_parent_name );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setExpression_number( ref_expression_number );
    }
    @Override
    public void setRoot_expression_number( String ref_root_expression_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setRoot_expression_number( ref_root_expression_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setParent_package( ref_parent_package );
    }
    @Override
    public void setIndex_expression_number( String ref_index_expression_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setIndex_expression_number( ref_index_expression_number );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setBody_name( ref_body_name );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setBlock_number( ref_block_number );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setStatement_number( ref_statement_number );
    }


    // selections
    @Override
    public ExpressionSet R3900_has_root_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ArrayElementReference arrayelementreference : this ) expressionset.add( arrayelementreference.R3900_has_root_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R3901_has_index_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ArrayElementReference arrayelementreference : this ) expressionset.add( arrayelementreference.R3901_has_index_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ArrayElementReference arrayelementreference : this ) expressionset.add( arrayelementreference.R776_is_a_Expression() );
        return expressionset;
    }


    @Override
    public ArrayElementReference nullElement() {
        return ArrayElementReferenceImpl.EMPTY_ARRAYELEMENTREFERENCE;
    }

    @Override
    public ArrayElementReferenceSet emptySet() {
      return new ArrayElementReferenceSetImpl();
    }

    @Override
    public ArrayElementReferenceSet value() {
        return this;
    }

    @Override
    public List<ArrayElementReference> elements() {
        return Arrays.asList(toArray(new ArrayElementReference[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/expression/impl/ArrayElementReferenceSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ArrayElementReference;
import io.ciera.tool.sql.architecture.expression.ArrayElementReferenceSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ArrayElementReferenceSetImpl extends InstanceSet<ArrayElementReferenceSet,ArrayElementReference> implements ArrayElementReferenceSet {

    public ArrayElementReferenceSetImpl() {
    }

    public ArrayElementReferenceSetImpl(Comparator<? super ArrayElementReference> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setParent_name( ref_parent_name );
    }
    @Override
    public void setIndex_expression_number( String ref_index_expression_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setIndex_expression_number( ref_index_expression_number );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setStatement_number( ref_statement_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setParent_package( ref_parent_package );
    }
    @Override
    public void setRoot_expression_number( String ref_root_expression_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setRoot_expression_number( ref_root_expression_number );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setExpression_number( ref_expression_number );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setBody_name( ref_body_name );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( ArrayElementReference arrayelementreference : this ) arrayelementreference.setBlock_number( ref_block_number );
    }


    // selections
    @Override
    public ExpressionSet R3900_has_root_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ArrayElementReference arrayelementreference : this ) expressionset.add( arrayelementreference.R3900_has_root_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R3901_has_index_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ArrayElementReference arrayelementreference : this ) expressionset.add( arrayelementreference.R3901_has_index_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ArrayElementReference arrayelementreference : this ) expressionset.add( arrayelementreference.R776_is_a_Expression() );
        return expressionset;
    }


    @Override
    public ArrayElementReference nullElement() {
        return ArrayElementReferenceImpl.EMPTY_ARRAYELEMENTREFERENCE;
    }

    @Override
    public ArrayElementReferenceSet emptySet() {
      return new ArrayElementReferenceSetImpl();
    }

    @Override
    public ArrayElementReferenceSet emptySet(Comparator<? super ArrayElementReference> comp) {
      return new ArrayElementReferenceSetImpl(comp);
    }

    @Override
    public ArrayElementReferenceSet value() {
        return this;
    }

    @Override
    public List<ArrayElementReference> elements() {
        return Arrays.asList(toArray(new ArrayElementReference[0]));
    }

}
